==> jc-1.4.0.tar.gz: java/util/jar/JarInputStream.h <==
// public class java.util.jar.JarInputStream

// class file dependencies
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 45d5a1881118eaaa java_util_jar_JarInputStream
// @dep_class 5602700a47802920 java_util_zip_InflaterInputStream
// @dep_class 6587d25494e415a2 java_util_zip_ZipInputStream

// header file dependencies
// @dep_header java_util_zip_ZipInputStream

#include "java/util/zip/ZipInputStream.h"

#ifndef _JC_java_util_jar_JarInputStream_H_
#define _JC_java_util_jar_JarInputStream_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_jar_JarEntry$object;
struct _jc_java_util_jar_Manifest$object;
struct _jc_java_util_zip_ZipEntry$object;

// Typedefs
typedef struct _jc_java_util_jar_JarInputStream$sub_refs	_jc_java_util_jar_JarInputStream$sub_refs;
typedef struct _jc_java_util_jar_JarInputStream$sub_nonrefs	_jc_java_util_jar_JarInputStream$sub_nonrefs;
typedef struct _jc_java_util_jar_JarInputStream$refs	_jc_java_util_jar_JarInputStream$refs;
typedef struct _jc_java_util_jar_JarInputStream$nonrefs	_jc_java_util_jar_JarInputStream$nonrefs;
typedef struct _jc_java_util_jar_JarInputStream$object	_jc_java_util_jar_JarInputStream$object;

typedef const struct _jc_java_util_jar_JarInputStream$vmethods	_jc_java_util_jar_JarInputStream$vmethods;
typedef const struct _jc_java_util_jar_JarInputStream$vtable	_jc_java_util_jar_JarInputStream$vtable;
typedef const struct _jc_java_util_jar_JarInputStream$vtype	_jc_java_util_jar_JarInputStream$vtype;

// Constructors
extern void _jc_java_util_jar_JarInputStream$method$_init$3887600c17c5e554(_jc_env *, struct _jc_java_util_jar_JarInputStream$object *, struct _jc_java_io_InputStream$object *);
extern void _jc_java_util_jar_JarInputStream$method$_init$90b421b573adfbb5(_jc_env *, struct _jc_java_util_jar_JarInputStream$object *, struct _jc_java_io_InputStream$object *, jboolean);

// Virtual methods
extern struct _jc_java_util_zip_ZipEntry$object *_jc_java_util_jar_JarInputStream$method$createZipEntry$3e6190033d3b6bac(_jc_env *, struct _jc_java_util_jar_JarInputStream$object *, struct _jc_java_lang_String$object *);
extern struct _jc_java_util_jar_Manifest$object *_jc_java_util_jar_JarInputStream$method$getManifest$eaf02229f23f92a3(_jc_env *, struct _jc_java_util_jar_JarInputStream$object *);
extern struct _jc_java_util_zip_ZipEntry$object *_jc_java_util_jar_JarInputStream$method$getNextEntry$37c60ebf27303f95(_jc_env *, struct _jc_java_util_jar_JarInputStream$object *);
extern struct _jc_java_util_jar_JarEntry$object *_jc_java_util_jar_JarInputStream$method$getNextJarEntry$c0f4d5191f30d26d(_jc_env *, struct _jc_java_util_jar_JarInputStream$object *);
extern jint _jc_java_util_jar_JarInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_java_util_jar_JarInputStream$object *, struct _jc_byte_array *, jint, jint);
extern void _jc_java_util_jar_JarInputStream$method$readManifest$fecc2520771c90f4(_jc_env *, struct _jc_java_util_jar_JarInputStream$object *, jboolean);

// Virtual method descriptors
extern _jc_method _jc_java_util_jar_JarInputStream$method_info$createZipEntry$3e6190033d3b6bac;
extern _jc_method _jc_java_util_jar_JarInputStream$method_info$getManifest$eaf02229f23f92a3;
extern _jc_method _jc_java_util_jar_JarInputStream$method_info$getNextEntry$37c60ebf27303f95;
extern _jc_method _jc_java_util_jar_JarInputStream$method_info$getNextJarEntry$c0f4d5191f30d26d;
extern _jc_method _jc_java_util_jar_JarInputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_java_util_jar_JarInputStream$method_info$readManifest$fecc2520771c90f4;

// Virtual methods structure
struct _jc_java_util_jar_JarInputStream$vmethods {
	struct _jc_java_util_zip_ZipEntry$object	*(*createZipEntry$3e6190033d3b6bac)(_jc_env *, struct _jc_java_util_jar_JarInputStream$object *, struct _jc_java_lang_String$object *);
	struct _jc_java_util_jar_Manifest$object	*(*getManifest$eaf02229f23f92a3)(_jc_env *, struct _jc_java_util_jar_JarInputStream$object *);
	struct _jc_java_util_zip_ZipEntry$object	*(*getNextEntry$37c60ebf27303f95)(_jc_env *, struct _jc_java_util_jar_JarInputStream$object *);
	struct _jc_java_util_jar_JarEntry$object	*(*getNextJarEntry$c0f4d5191f30d26d)(_jc_env *, struct _jc_java_util_jar_JarInputStream$object *);
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_java_util_jar_JarInputStream$object *, struct _jc_byte_array *, jint, jint);
	void	(*readManifest$fecc2520771c90f4)(_jc_env *, struct _jc_java_util_jar_JarInputStream$object *, jboolean);
};

// Vtable
struct _jc_java_util_jar_JarInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_java_util_zip_InflaterInputStream$vmethods	java_util_zip_InflaterInputStream;
	_jc_java_util_zip_ZipInputStream$vmethods	java_util_zip_ZipInputStream;
	_jc_java_util_jar_JarInputStream$vmethods	java_util_jar_JarInputStream;
};

// Vtype
struct _jc_java_util_jar_JarInputStream$vtype {
	_jc_type			type;
	_jc_java_util_jar_JarInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_jar_JarInputStream$sub_refs {
	struct _jc_java_util_jar_Manifest$object	*manifest;
	struct _jc_java_util_jar_JarEntry$object	*firstEntry;
};

// Reference instance fields (object)
struct _jc_java_util_jar_JarInputStream$refs {
    _jc_java_util_jar_JarInputStream$sub_refs	java_util_jar_JarInputStream;
    _jc_java_util_zip_ZipInputStream$sub_refs	java_util_zip_ZipInputStream;
    _jc_java_util_zip_InflaterInputStream$sub_refs	java_util_zip_InflaterInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_jar_JarInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_jar_JarInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_java_util_zip_InflaterInputStream$sub_nonrefs	java_util_zip_InflaterInputStream;
    _jc_java_util_zip_ZipInputStream$sub_nonrefs	java_util_zip_ZipInputStream;
    _jc_java_util_jar_JarInputStream$sub_nonrefs	java_util_jar_JarInputStream;
};

// Object instance structure
struct _jc_java_util_jar_JarInputStream$object {
	_jc_java_util_jar_JarInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_jar_JarInputStream$vtype	*vtype;
	_jc_java_util_jar_JarInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_jar_JarInputStream$vtype _jc_java_util_jar_JarInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_jar_JarInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_jar_JarInputStream$class_object;

#endif	/* _JC_java_util_jar_JarInputStream_H_ */

==> jc-1.4.6.tar.gz: java/util/jar/JarInputStream.h <==
// public class java.util.jar.JarInputStream

// class file dependencies
// @dep_class 455accfa535f5dfe java_io_FilterInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 45d5a1881118eaaa java_util_jar_JarInputStream
// @dep_class 5602700a47802920 java_util_zip_InflaterInputStream
// @dep_class 6587d25494e415a2 java_util_zip_ZipInputStream

// header file dependencies
// @dep_header java_util_zip_ZipInputStream

#include "java/util/zip/ZipInputStream.h"

#ifndef _JC_java_util_jar_JarInputStream_H_
#define _JC_java_util_jar_JarInputStream_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_jar_JarEntry$object;
struct _jc_java_util_jar_Manifest$object;
struct _jc_java_util_zip_ZipEntry$object;

// Typedefs
typedef struct _jc_java_util_jar_JarInputStream$sub_refs	_jc_java_util_jar_JarInputStream$sub_refs;
typedef struct _jc_java_util_jar_JarInputStream$sub_nonrefs	_jc_java_util_jar_JarInputStream$sub_nonrefs;
typedef struct _jc_java_util_jar_JarInputStream$refs	_jc_java_util_jar_JarInputStream$refs;
typedef struct _jc_java_util_jar_JarInputStream$nonrefs	_jc_java_util_jar_JarInputStream$nonrefs;
typedef struct _jc_java_util_jar_JarInputStream$object	_jc_java_util_jar_JarInputStream$object;

typedef const struct _jc_java_util_jar_JarInputStream$vmethods	_jc_java_util_jar_JarInputStream$vmethods;
typedef const struct _jc_java_util_jar_JarInputStream$vtable	_jc_java_util_jar_JarInputStream$vtable;
typedef const struct _jc_java_util_jar_JarInputStream$vtype	_jc_java_util_jar_JarInputStream$vtype;

// Constructors
extern void _jc_java_util_jar_JarInputStream$method$_init$3887600c17c5e554(_jc_env *, struct _jc_java_util_jar_JarInputStream$object *, struct _jc_java_io_InputStream$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_jar_JarInputStream$method$_init$90b421b573adfbb5(_jc_env *, struct _jc_java_util_jar_JarInputStream$object *, struct _jc_java_io_InputStream$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_util_zip_ZipEntry$object *_jc_java_util_jar_JarInputStream$method$createZipEntry$3e6190033d3b6bac(_jc_env *, struct _jc_java_util_jar_JarInputStream$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_jar_Manifest$object *_jc_java_util_jar_JarInputStream$method$getManifest$eaf02229f23f92a3(_jc_env *, struct _jc_java_util_jar_JarInputStream$object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_zip_ZipEntry$object *_jc_java_util_jar_JarInputStream$method$getNextEntry$37c60ebf27303f95(_jc_env *, struct _jc_java_util_jar_JarInputStream$object *) _JC_JCNI_ATTR;
extern struct _jc_java_util_jar_JarEntry$object *_jc_java_util_jar_JarInputStream$method$getNextJarEntry$c0f4d5191f30d26d(_jc_env *, struct _jc_java_util_jar_JarInputStream$object *) _JC_JCNI_ATTR;
extern jint _jc_java_util_jar_JarInputStream$method$read$e6b6c87b9f256783(_jc_env *, struct _jc_java_util_jar_JarInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_java_util_jar_JarInputStream$method$readManifest$fecc2520771c90f4(_jc_env *, struct _jc_java_util_jar_JarInputStream$object *, jboolean) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_jar_JarInputStream$method_info$createZipEntry$3e6190033d3b6bac;
extern _jc_method _jc_java_util_jar_JarInputStream$method_info$getManifest$eaf02229f23f92a3;
extern _jc_method _jc_java_util_jar_JarInputStream$method_info$getNextEntry$37c60ebf27303f95;
extern _jc_method _jc_java_util_jar_JarInputStream$method_info$getNextJarEntry$c0f4d5191f30d26d;
extern _jc_method _jc_java_util_jar_JarInputStream$method_info$read$e6b6c87b9f256783;
extern _jc_method _jc_java_util_jar_JarInputStream$method_info$readManifest$fecc2520771c90f4;

// Virtual methods structure
struct _jc_java_util_jar_JarInputStream$vmethods {
	struct _jc_java_util_zip_ZipEntry$object	*(*createZipEntry$3e6190033d3b6bac)(_jc_env *, struct _jc_java_util_jar_JarInputStream$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_java_util_jar_Manifest$object	*(*getManifest$eaf02229f23f92a3)(_jc_env *, struct _jc_java_util_jar_JarInputStream$object *) _JC_JCNI_ATTR;
	struct _jc_java_util_zip_ZipEntry$object	*(*getNextEntry$37c60ebf27303f95)(_jc_env *, struct _jc_java_util_jar_JarInputStream$object *) _JC_JCNI_ATTR;
	struct _jc_java_util_jar_JarEntry$object	*(*getNextJarEntry$c0f4d5191f30d26d)(_jc_env *, struct _jc_java_util_jar_JarInputStream$object *) _JC_JCNI_ATTR;
	jint	(*read$e6b6c87b9f256783)(_jc_env *, struct _jc_java_util_jar_JarInputStream$object *, struct _jc_byte_array *, jint, jint) _JC_JCNI_ATTR;
	void	(*readManifest$fecc2520771c90f4)(_jc_env *, struct _jc_java_util_jar_JarInputStream$object *, jboolean) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_jar_JarInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_FilterInputStream$vmethods	java_io_FilterInputStream;
	_jc_java_util_zip_InflaterInputStream$vmethods	java_util_zip_InflaterInputStream;
	_jc_java_util_zip_ZipInputStream$vmethods	java_util_zip_ZipInputStream;
	_jc_java_util_jar_JarInputStream$vmethods	java_util_jar_JarInputStream;
};

// Vtype
struct _jc_java_util_jar_JarInputStream$vtype {
	_jc_type			type;
	_jc_java_util_jar_JarInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_jar_JarInputStream$sub_refs {
	struct _jc_java_util_jar_Manifest$object	*manifest;
	struct _jc_java_util_jar_JarEntry$object	*firstEntry;
};

// Reference instance fields (object)
struct _jc_java_util_jar_JarInputStream$refs {
    _jc_java_util_jar_JarInputStream$sub_refs	java_util_jar_JarInputStream;
    _jc_java_util_zip_ZipInputStream$sub_refs	java_util_zip_ZipInputStream;
    _jc_java_util_zip_InflaterInputStream$sub_refs	java_util_zip_InflaterInputStream;
    _jc_java_io_FilterInputStream$sub_refs	java_io_FilterInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_jar_JarInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_jar_JarInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_FilterInputStream$sub_nonrefs	java_io_FilterInputStream;
    _jc_java_util_zip_InflaterInputStream$sub_nonrefs	java_util_zip_InflaterInputStream;
    _jc_java_util_zip_ZipInputStream$sub_nonrefs	java_util_zip_ZipInputStream;
    _jc_java_util_jar_JarInputStream$sub_nonrefs	java_util_jar_JarInputStream;
};

// Object instance structure
struct _jc_java_util_jar_JarInputStream$object {
	_jc_java_util_jar_JarInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_jar_JarInputStream$vtype	*vtype;
	_jc_java_util_jar_JarInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_jar_JarInputStream$vtype _jc_java_util_jar_JarInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_jar_JarInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_jar_JarInputStream$class_object;

#endif	/* _JC_java_util_jar_JarInputStream_H_ */
